require "schoolkeep/cli"
require "tmpdir"
require "yaml"
require "open3"

module Schoolkeep
  RSpec.describe CLI do
    describe "#reset" do
      it "returns an error when there is an invalid template name" do
        _, error, process = Open3.capture3 "SK_API_KEY=test #{bin_path} reset non_existetnt_file.sktl"

        expect(process).not_to be_success
        expect(error).to include "invalid template name"
      end
    end

    describe "#generate-fixtures" do
      it "copies the fixture file" do
        Dir.mktmpdir do |dir|
          output, _, process = Open3.capture3 "#{bin_path} generate-fixtures --dir #{dir}"
          expect(process).to be_success
          expect(output).to include "fixtures.yml has been generated"
          expect(File.exist?(File.join(dir, "config/fixtures.yml"))).to be true
        end
      end
    end

    describe "#server" do
      it "serves directory" do
        Dir.mktmpdir do |dir|
          Dir.mkdir "#{dir}/templates"
          File.write "#{dir}/templates/custom_page.html.sktl", ""

          port = find_available_port
          @pid = spawn("#{bin_path} server --dir #{dir} --port #{port} --quiet")

          Timeout.timeout(60) { sleep 0.1 until responsive?(port) }

          response = Faraday.get("http://localhost:#{port}/")
          expect(response.body).to include "custom_page.html.sktl"
        end
      end

      after do
        Process.kill("INT", @pid) if @pid
      end

      def responsive?(port)
        res = Faraday.get("http://localhost:#{port}/")

        if res.success?
          return res.body.include?("custom_page.html.sktl")
        end
      rescue Faraday::ConnectionFailed
        return false
      end

      def find_available_port
        server = TCPServer.new('127.0.0.1', 0)
        server.addr[1]
      ensure
        server.close if server
      end
    end

    def bin_path
      @bin_path ||= File.expand_path("../../bin/sk", __FILE__)
    end
  end
end
