require "schoolkeep/cli"
require "schoolkeep/client"
require "tmpdir"
require "yaml"

module Schoolkeep
  RSpec.describe CLI, :schoolkeep_client, type: :feature do
    describe "#upload and #reset" do
      it "uploads the all templates and then deletes it" do
        Dir.mktmpdir do |template_dir|
          test_string = rand(36**100).to_s(36)
          TEMPLATE_NAMES.each do |name|
            File.write "#{template_dir}/#{name}.sktl", test_string
          end

          expect(system("#{bin_path} upload --dir #{template_dir} --quiet --all")).to be true

          response = Faraday.get(ENV["SK_CUSTOM_PAGE_URL"])
          expect(response.body).to include test_string

          expect(system("#{bin_path} reset --all --quiet")).to be true

          response = Faraday.get(ENV["SK_CUSTOM_PAGE_URL"])
          expect(response.body).not_to include test_string
        end
      end

      it "uploads the all templates and then deletes it" do
        Dir.mktmpdir do |template_dir|
          test_string = rand(36**100).to_s(36)
          custom_page_path = File.join(template_dir, "custom_page.html.sktl")
          File.write custom_page_path, test_string

          expect(system("#{bin_path} upload #{custom_page_path} --quiet")).to be true

          response = Faraday.get(ENV["SK_CUSTOM_PAGE_URL"])
          expect(response.body).to include test_string

          expect(system("#{bin_path} reset custom_page.html.sktl --quiet")).to be true

          response = Faraday.get(ENV["SK_CUSTOM_PAGE_URL"])
          expect(response.body).not_to include test_string
        end
      end
    end

    def bin_path
      @bin_path ||= File.expand_path("../../../bin/sk", __FILE__)
    end
  end
end
