require "schoolkeep/client"
require "tempfile"

module Schoolkeep
  RSpec.describe Client, :schoolkeep_client, type: :feature do
    describe "#upload and #delete" do
      it "deletes the custom_page template" do
        expect(client.upload("custom_page.html", temp_file, "sktl")).to be_success
        response = Faraday.get(ENV["SK_CUSTOM_PAGE_URL"])

        expect(response.body).to include test_string

        expect(client.delete("custom_page.html")).to be_success
        response = Faraday.get(ENV["SK_CUSTOM_PAGE_URL"])

        expect(response.body).not_to include test_string
      end

      after do
        temp_file.unlink
      end

      def test_string
        @test_string ||= rand(36**100).to_s(36)
      end

      def temp_file
        @temp_file ||= Tempfile.new("any_file.sktl").tap do |file|
          file.write(test_string)
          file.rewind
        end
      end
    end

    describe "#get_fixtures" do
      it "downloads fixtures" do
        response = client.get_fixtures

        expect(response).to be_success
        expect(YAML.load(response.body)).to have_key "globals"
      end
    end

    def client
      @client ||= Client.new(ENV["SK_API_KEY"])
    end
  end
end
