require "schoolkeep/fixture"

module Schoolkeep
  RSpec.describe Fixture do
    describe "#globals" do
      it "reads global file and needs no dev file" do
        globals = Fixture.new(nil).globals

        expect(globals[:current_learner].name).to eq "Test Learner"
      end

      it "reads global file and uses dev overwrites" do
        file = Tempfile.new(%w(fixture yml))

        begin
          file.write(dev_fixtures.to_yaml)
          file.rewind
          globals = Fixture.new(file.path).globals
          expect(globals[:current_learner].name).to eq "Fixture Test"
        ensure
          file.close
          file.unlink   # deletes the temp file
        end
      end

      def dev_fixtures
        {"globals" => { "current_learner" => {"name" => "Fixture Test"}}}
      end
    end

    describe "#for" do
      it "reads global file and needs no dev file" do
        fixtures = Fixture.new(nil).for("custom_page.html.sktl")
        expect(fixtures[:custom_page].headline).to eq "Sample Custom Page"
      end

      it "renders all templates without errors" do
        Schoolkeep::TEMPLATE_NAMES.each do |name|
          Fixture.new(nil).for("#{name}.sktl")
        end
      end

      it "reads global file and uses dev overwrites" do
        file = Tempfile.new(%w(fixture yml))

        begin
          file.write(dev_fixtures.to_yaml)
          file.rewind
          fixtures = Fixture.new(file.path).for("custom_page.html.sktl")
          expect(fixtures[:custom_page].headline).to eq "Fixture Test"
        ensure
          file.close
          file.unlink   # deletes the temp file
        end
      end

      it "properly references courses" do
        fixtures = Fixture.new(nil).for("course_details.html.sktl")

        expect(fixtures[:course].name).to eq "photography course"
      end

      def dev_fixtures
        { "templates" => { "custom_page.html.sktl" => { "custom_page" => {"headline" => "Fixture Test"}}}}
      end
    end
  end
end
