require "scribble"
require "schoolkeep/scribble/methods/pluralize"
require "active_support/core_ext/string/inflections"

module Scribble::Methods
  RSpec.describe Pluralize do
    describe "#pluralize" do
      after do
        I18n.locale = I18n.default_locale
        ActiveSupport::Inflector.inflections(:es) do |inflect|
          inflect.clear
        end
      end

      it "uses locale to pluralize string if none specified" do
        ActiveSupport::Inflector.inflections(:es) do |inflect|
          inflect.clear

          inflect.plural(/$/, 's')
          inflect.plural(/([^aeéiou])$/i, '\1es')
        end

        I18n.locale = :es

        expect(render("{{pluralize(0, 'ley')}}")).to eq "leyes"
        expect(render("{{pluralize(1, 'ley')}}")).to eq "ley"
        expect(render("{{pluralize(2, 'ley')}}")).to eq "leyes"
      end

      it "uses specified attribute to pluralize string" do
        expect(render("{{pluralize(0, 'one', 'many')}}")).to eq "many"
        expect(render("{{pluralize(1, 'one', 'many')}}")).to eq "one"
        expect(render("{{pluralize(2, 'one', 'many')}}")).to eq "many"
      end
    end

    def render(source)
      Scribble::Template.new(source).render
    end
  end
end
