require "scribble"
require "schoolkeep/scribble/methods/script"

module Scribble::Methods
  RSpec.describe Script do
    describe "#script" do
      it "renders a script tag for the fingerprinted asset" do
        rendered = render("{{ script('hello') }}", "test_template")

        expect(rendered).to eq "<script src='/custom_assets/abc123/hello-zxy987.js'></script>"
      end

      context "when there is an asset host" do
        it "renders the host" do
          rendered = render(
            "{{ script('hello') }}",
            "test_template",
            asset_host: "foo.com"
          )

          expect(rendered).to eq \
            "<script src='foo.com/custom_assets/abc123/hello-zxy987.js'></script>"
        end
      end
    end

    def render(source, template_name, locale: :en, asset_host: nil)
      url_helpers = double(:url_helpers)
      routes = double(:routes, url_helpers: url_helpers)
      school = double(:school, uuid: "abc123", routes: routes)
      template = double(:template, fingerprint: "zxy987")
      custom_templates = double(:custom_templates, find_by!: template)
      allow(url_helpers).to receive(:custom_asset_url) do |school_uuid, asset|
        [
          asset_host,
          "custom_assets",
          school_uuid,
          asset
        ].join("/")
      end

      Scribble::Template.new(source).render(
        variables: {
          asset_host: asset_host,
          custom_templates: custom_templates,
          current_school: school,
          template_name: template_name
        }
      )
    end
  end
end
