require "schoolkeep/server"
require "faraday"

module Schoolkeep
  RSpec.describe Server do
    describe "#server" do
      it "serves the templates locally" do
        I18n.locale = :en
        Dir.mktmpdir do |dir|
          Dir.mkdir "#{dir}/templates"
          File.write "#{dir}/templates/_head.html.sktl", "<!-- HTML_HEAD -->"
          File.write "#{dir}/templates/_header.html.sktl", "HEADER {{t('.courses')}}"
          File.write "#{dir}/templates/_footer.html.sktl", "FOOTER {{t('.connect')}}"
          File.write "#{dir}/templates/custom_page.html.sktl", "BODY {{custom_page.page_title}}"
          Dir.mkdir "#{dir}/config"
          File.write "#{dir}/config/fixtures.yml", fixtures.to_yaml

          port = find_available_port

          @server_thread = Thread.new do
            Server.new(dir: dir, port: port, quiet: true).start
          end

          Timeout.timeout(60) { @server_thread.join(0.1) until responsive?(port) }

          response = Faraday.get("http://localhost:#{port}/custom_page.html.sktl")

          expect(response.body).to include "HTML_HEAD"
          expect(response.body).to include "HEADER"
          expect(response.body).to include "school_website-custom_pages school_website-custom_pages-show"
          expect(response.body).to include I18n.t("custom_templates._header.courses")
          expect(response.body).to include "BODY"
          expect(response.body).to include page_title
          expect(response.body).to include "FOOTER"
          expect(response.body).to include I18n.t("custom_templates._footer.connect")
        end
      end

      after do
        @server_thread.exit
      end

      def responsive?(port)
        return false if @server_thread && @server_thread.join(0)

        res = Faraday.get("http://localhost:#{port}/")

        if res.success?
          return res.body.include?("custom_page.html.sktl")
        end
      rescue Faraday::ConnectionFailed
        return false
      end

      def port
        @port ||= find_available_port
      end

      def fixtures
        {
          "templates" => {
            "custom_page.html.sktl" => {
              custom_page: { page_title: page_title}
            }
          }
        }
      end

      def page_title
        @page_title ||= "This is an awesome title"
      end

      def find_available_port
        server = TCPServer.new('127.0.0.1', 0)
        server.addr[1]
      ensure
        server.close if server
      end
    end
  end
end
