require 'delegate'

module Support
  GEM_ROOT = File.expand_path("../../", __FILE__)
  class WarningFilter < DelegateClass(IO)
    def write(line)
      super if line.start_with?(GEM_ROOT)
    end
  end
end

$stderr = Support::WarningFilter.new($stderr)

require "pry"
require "i18n"

RSpec.configure do |config|
  config.filter_run_excluding schoolkeep_client: true

  config.expect_with :rspec do |expectations|
    expectations.include_chain_clauses_in_custom_matcher_descriptions = true
  end

  config.mock_with :rspec do |mocks|
    mocks.verify_partial_doubles = true
  end

  config.filter_run :focus
  config.run_all_when_everything_filtered = true

  config.disable_monkey_patching!

  config.warnings = true

  if config.files_to_run.one?
    config.default_formatter = 'doc'
  end

  config.profile_examples = 10

  config.order = :random

  Kernel.srand config.seed
end

I18n.available_locales = [:en, :es]
I18n.backend.store_translations(:en, {bar: "baz", custom_templates: { test_template: { foo: "bar" }}})
I18n.backend.store_translations(:es, {bar: "el_baz", custom_templates: { test_template: { foo: "el_bar" }}})
